``resmda`` - ES-MDA with a simple 2D reservoir modeller
=======================================================

A simple 2D reservoir simulator and a straight-forward implementation of the
basic *Ensemble smoother with multiple data assimilation* (ES-MDA) algorithm as
presented by Emerick and Reynolds, 2013.

- **Documentation:** https://tuda-geo.github.io/resmda
- **Source Code:** https://github.com/tuda-geo/resmda
- **Bug reports:** https://github.com/tuda-geo/resmda/issues


Available through pip and conda:
``pip install resmda`` / ``conda install -c conda-forge resmda``.

